@@ -81,7 +81,7 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
 
     # Take the countries of the campaign from the config file
     countries_list = config['countries_list']
-    df = devutils.filter_countries( df=df, countries=countries_list )
+    df = devutils.filter_countries( df=df, countries=countries_list,fixed_filter=config['fixed_countries'] )
 
     # Fix errors in CompanyFollowers
     df = devutils.clean_companyfollowers_text( df=df )
